# eConEXG
SDKs for Niantong devices.

[![Rye](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/rye/main/artwork/badge.json)](https://rye-up.com)

For more information, see the online [documentation](https://niantong-intelligence.github.io/eConEXG/).
<!-- released start -->
## Installation

*  **Online:**

    `pip install econexg`

*  **Offline:**

    `pip install econexg-x.x.x-py3-none-any.whl`

    ##### * Network connection is required to download dependencies.

#### Optional dependencies can be installed via `pip install econexg[option1,option2,...]`

* Available options:
    * bdf: save to BDF file functionality support.
    * lsl: LSL stream functionality support.
    * wifi: iRecorder W32 wifi model support, msvc build tools required.

## Quick Start

Example code can be found in [examples](https://github.com/Niantong-Intelligence/eConEXG/tree/main/examples).

## Platform Support
| Hardware            | Windows       | macOS          | Linux         |
|------------------|-----------------|--------------|---------------|
| iRecorder USB | ✓ |   ✓  |    ✓  |
| iRecorder W8 \| W16  | ✓ | 𐄂    | 𐄂     |
| iRecorder W32 | ✓ |   ✓  |    ✓  |
| iFocus        | ✓ |   ✓  |    ✓  |
| TriggerBox    | ✓ |   ✓  |    ✓  |


## More

* [Discussion Forum](https://github.com/Niantong-Intelligence/eConEXG/discussions), to discuss the project
  on GitHub
* [Issue Tracker](https://github.com/Niantong-Intelligence/eConEXG/issues), if you run into bugs or have suggestions
* License: MIT